# Kutubhona 

**Kutubhona** — bu O'zbekistonning zamonaviy Python kutubxonasi!  
Kutubhona dasturchilarga qulay interfeys orqali ma'lumotlar bilan ishlash imkonini beradi. Bu kutubxona O'zbekistondagi dasturchilar ehtiyojlarini hisobga olgan holda ishlab chiqilgan.  

Tashkent (Toshkent)
Andijan (Andijon)
Bukhara (Buxoro)
Gulistan (Guliston)
Jizzakh (Jizzax)
Zarafshan (Zarafshon)
Karshi (Qarshi)
Navoi (Navoiy)
Namangan
Nukus
Samarkand (Samarqand)
Termez (Termiz)
Urgench (Urganch)
Ferghana (Farg'ona)
Khiva (Xiva)
Sirdarya (Sir Daryo)
Surkhandarya (Surxondaryo)
Kashkadarya (Kashkadaryo)
Khorezm (Xorazm)

---

## O'rnatish

Kutubxonani o'rnatish juda oson:

```bash
pip install weatheruz
